@@ -12,11 +12,13 @@ from SharedData.SharedDataAWSS3 import S3SyncDownloadMetadata,S3Upload
 
 class Metadata():
     
-    def __init__(self, name, mode='rw', sync_frequency_days=0, user='master'):
+    def __init__(self, name, mode='rw', user='master',debug=False):
+        self.debug = debug
+
         if Logger.log is None:
             Logger('Metadata')
-
-        Logger.log.debug('Initializing Metadata %s,%s,%s ...' % (user,name,mode))
+        if self.debug:
+            Logger.log.debug('Initializing Metadata %s,%s,%s ...' % (user,name,mode))
         self.user = user
         
         self.s3read = False
@@ -43,30 +45,9 @@ class Metadata():
         self.pathsymbols = self.fpath /  ('Metadata/'+name+'_SYMBOLS.pkl')
         self.pathseries = self.fpath /  ('Metadata/'+name+'_SERIES.pkl')
 
-        if (self.s3read):
-
-            self.lastsync = pd.DataFrame([])
-            self.lastsyncfpath = Path(os.environ['DATABASE_FOLDER']) / (user+'/Metadata/lastsync.txt')
-            if self.lastsyncfpath.is_file():
-                self.lastsync = pd.read_csv(self.lastsyncfpath)
-                self.lastsync = self.lastsync.set_index('file')
-                self.lastsync['timestamp'] = pd.to_datetime(self.lastsync['timestamp'])
-
-            now = datetime.utcnow()
-            sync = False
-            if not self.name in self.lastsync.index:
-                sync = True
-            else:
-                td = (now - self.lastsync['timestamp'][self.name]).seconds/86400
-                if td>sync_frequency_days:
-                    sync = True
-
-            if sync:
-                if S3SyncDownloadMetadata(self.pathpkl,self.name):
-                    self.lastsync.loc[self.name,'timestamp'] = now
-                    self.lastsync.index.name = 'file'
-                    self.lastsync.to_csv(self.lastsyncfpath)       
-
+        if (self.s3read):            
+            S3SyncDownloadMetadata(self.pathpkl,self.name)
+                    
         # prefer read pkl
         # but read excel if newer
         readpkl = self.pathpkl.is_file()
@@ -77,7 +58,8 @@ class Metadata():
         
         if readpkl:
             tini = time.time()
-            Logger.log.debug('Loading metadata pkl ' + name + ' ...')
+            if self.debug:
+                Logger.log.debug('Loading metadata pkl ' + name + ' ...')
             self.static = pd.read_pickle(self.pathpkl)
             self.static = self.static.sort_index()
             if self.pathsymbols.is_file():
@@ -86,7 +68,8 @@ class Metadata():
             if self.pathseries.is_file():
                 self.series = pd.read_pickle(self.pathseries)
                 self.series = self.series.sort_index()
-            Logger.log.debug('Loading metadata pkl %s %.2f done!' % (name,time.time()-tini))
+            if self.debug:
+                Logger.log.debug('Loading metadata pkl %s %.2f done!' % (name,time.time()-tini))
 
         elif readxlsx:
             tini = time.time()
@@ -99,13 +82,16 @@ class Metadata():
                 self.static = self.static.set_index(self.static.columns[0])
             if not self.symbols.empty:
                 self.symbols = self.symbols.set_index(self.symbols.columns[0])
-            Logger.log.debug('Loading metadata xlsx %s %.2f done!' % (name,time.time()-tini))
+            if self.debug:
+                Logger.log.debug('Loading metadata xlsx %s %.2f done!' % (name,time.time()-tini))
         
-        Logger.log.debug('Initializing Metadata %s,%s DONE!' % (name,mode))
+        if self.debug:
+            Logger.log.debug('Initializing Metadata %s,%s DONE!' % (name,mode))
 
     def save(self,save_excel=False):
         tini = time.time()
-        Logger.log.debug('Saving metadata ' + self.name + ' ...')  
+        if self.debug:
+            Logger.log.debug('Saving metadata ' + self.name + ' ...')  
         if not os.path.isdir(self.pathpkl.parents[0]):
             os.makedirs(self.pathpkl.parents[0])                   
 
@@ -134,18 +120,19 @@ class Metadata():
             if self.s3write:
                 S3Upload(self.pathseries)
 
-
-        Logger.log.debug('Saving metadata ' + self.name + \
-            ' %.2f done!' % (time.time()-tini))
+        if self.debug:
+            Logger.log.debug('Saving metadata ' + self.name + \
+                ' %.2f done!' % (time.time()-tini))
     
     def mergeUpdate(self,newdf):
         ddidx = newdf.index.duplicated()
         if ddidx.any():
-            newdf = newdf[~newdf.index.duplicated(keep='first')]
+            newdf = newdf[~newdf.index.duplicated(keep='first')]            
             Logger.log.warning('Metadata merge duplicated index for new dataframe!')
         ddidx = self.static.index.duplicated()
         if ddidx.any():
             self.static = self.static[~self.static.index.duplicated(keep='first')]
+            
             Logger.log.warning('Metadata merge duplicated index for static dataframe!')
         newcolsidx = ~newdf.columns.isin(self.static.columns)
         if newcolsidx.any():
@@ -159,3 +146,9 @@ class Metadata():
         if newcol.any():
             self.static = self.static.reindex(columns=self.static.columns.union(newdf.columns))
         self.static.update(newdf)
+
+    def __setitem__(self, tag, value):
+        self.static[tag] = value
+                
+    def __getitem__(self, tag):
+        return self.static[tag]
\ No newline at end of file
