@@ -47,10 +47,7 @@ class SharedDataFeeder():
                 raise ValueError('Period '+period+ ' not supported!')
         return self.data[period]
 
-    def load_tag(self,period,tag):        
-        return self[period][tag]
-
-    def load_dataset(self, period='D1', tags=None):
+    def load(self, period='D1', tags=None):
             
         if not self.default_collections is None:
             for c in self.default_collections.replace('\n','').split(','):
@@ -71,15 +68,11 @@ class SharedDataFeeder():
                 futures = [exe.submit(self.load_tag, period, tag) for tag in tags]
                 # collect data
                 data = [future.result() for future in futures]
-
-
-    def save_tag(self, period, tag, startDate=None):
-        if startDate is None:
-            self[period].tags[tag].Write()
-        else:
-            self[period].tags[tag].Write(startDate=startDate)
-            
-    def save_dataset(self,  period='D1', tags=None, startDate=None):
+         
+    def load_tag(self,period,tag):        
+        return self[period][tag]
+ 
+    def save(self,  period='D1', tags=None, startDate=None):
 
         if not self.default_collections is None:
             for c in self.default_collections.replace('\n','').split(','):
@@ -100,3 +93,10 @@ class SharedDataFeeder():
                 futures = [exe.submit(self.save_tag, period, tag, startDate) for tag in tags]
                 # collect data
                 data = [future.result() for future in futures]
+
+    def save_tag(self, period, tag, startDate=None):
+        if startDate is None:
+            self[period].tags[tag].Write()
+        else:
+            self[period].tags[tag].Write(startDate=startDate)
+       
\ No newline at end of file
