@@ -8,6 +8,7 @@ from numba import jit
 from pandas.tseries.offsets import BDay
 from pathlib import Path
 from multiprocessing import shared_memory
+from concurrent.futures import ThreadPoolExecutor
 
 from subprocess import run, PIPE
 from datetime import datetime, timedelta
@@ -272,26 +273,36 @@ class SharedDataTimeSeries:
             if self.debug:
                 Logger.log.debug('Reading %s ...%.2f%% ' % (shm_name,0.0))   
             n=0
-            for f in files.index:
-                fpath=files.loc[f,'fpath']            
-                arr = np.load(str(fpath),mmap_mode='r')
-                r ,c = arr.shape
-                if (r>0):                   
-                    idxfpath = str(fpath).replace('.npy','.csv')
-                    with open(idxfpath,'r') as f:
-                        dfidx = f.read()
-                    dfidx = dfidx.split(',')
-                    sidx = [self.get_loc_symbol(s) for s in dfidx[1:]]
-                    sidx = np.array(sidx)                    
-                    ts = (arr[:,0]).astype(np.int64) #seconds
-                    tidx = self.get_loc_timestamp(ts)
-
-                    self.setValuesJit(self.data.values,tidx,sidx,arr[:,1:])
-                n=n+1                
+            self.read_multithread(files['fpath'])
             if self.debug:
                 Logger.log.debug('Reading %s ...%.2f%% %.2f sec! ' % \
                     (shm_name,100*(n/nfiles),time.time()-tini))
 
+    def read_multithread(self,file_paths):
+        # create a thread pool
+        with ThreadPoolExecutor(file_paths.shape[0]) as exe:
+            futures = [exe.submit(self.read_thread, fpath) \
+                for fpath in file_paths]
+            # collect data
+            data = [future.result() for future in futures]
+        
+    def read_thread(self,fpath):
+        arr = np.load(str(fpath),mmap_mode='r')
+        r ,c = arr.shape
+        if (r>0):                   
+            idxfpath = str(fpath).replace('.npy','.csv')
+            with open(idxfpath,'r') as f:
+                dfidx = f.read()
+            dfidx = dfidx.split(',')
+            sidx = [self.get_loc_symbol(s) for s in dfidx[1:]]
+            sidx = np.array(sidx)                    
+            ts = (arr[:,0]).astype(np.int64) #seconds
+            tidx = self.get_loc_timestamp(ts)
+
+            self.setValuesJit(self.data.values,tidx,sidx,arr[:,1:])
+            return True
+        return False
+                        
     def Write(self, busdays=None, startDate=None):
         tini = time.time()
         
@@ -312,33 +323,44 @@ class SharedDataTimeSeries:
         if self.debug:
             Logger.log.debug('Writing %s from %s ...%.2f%% ' % \
                 (shm_name,startdatestr,0.0))
-        
-            
+                
         years = self.data.loc[lastdate:,:].index.year.unique()
         ny = len(years)
         cy = 0        
-        for y in years:
-            idx = self.data.index[self.data.index.year==y]
-            dfyear = self.data.loc[idx,:].copy()
-            dfyear = dfyear.dropna(how='all').dropna(axis=1,how='all')
-            if dfyear.shape[0]>0:
-                dfyear.index = (dfyear.index.astype(np.int64)/10**9).astype(np.int64)
-                dfyear = dfyear.reset_index()
-
-                fpath_npy = path / (str(y)+'.npy')
-                np.save(str(fpath_npy),dfyear.values.astype(np.float64))
-                cols = ','.join(dfyear.columns)
-                fpath_csv = path / (str(y)+'.csv')
-                with open(fpath_csv, 'w') as f:
-                    f.write(cols)
-                if self.sharedData.s3write:
-                    S3Upload(fpath_npy)
-                    S3Upload(fpath_csv)
-                cy=cy+1      
+        self.write_multithread(years,path)
+        
         if self.debug:
             Logger.log.debug('Writing %s from %s ...%.2f%% %.2f sec!' % \
                 (shm_name,startdatestr,100*cy/ny,time.time()-tini))        
             
+    def write_multithread(self, years, path):
+        # create a thread pool
+        with ThreadPoolExecutor(years.shape[0]) as exe:
+            futures = [exe.submit(self.write_thread, year, path) \
+                for year in years]
+            # collect data
+            data = [future.result() for future in futures]
+        
+
+    def write_thread(self,y, path):
+        idx = self.data.index[self.data.index.year==y]
+        dfyear = self.data.loc[idx,:].copy()
+        dfyear = dfyear.dropna(how='all').dropna(axis=1,how='all')
+        if dfyear.shape[0]>0:
+            dfyear.index = (dfyear.index.astype(np.int64)/10**9).astype(np.int64)
+            dfyear = dfyear.reset_index()
+
+            fpath_npy = path / (str(y)+'.npy')
+            np.save(str(fpath_npy),dfyear.values.astype(np.float64))
+            cols = ','.join(dfyear.columns)
+            fpath_csv = path / (str(y)+'.csv')
+            with open(fpath_csv, 'w') as f:
+                f.write(cols)
+            if self.sharedData.s3write:
+                S3Upload(fpath_npy)
+                S3Upload(fpath_csv)
+            
+    
     def Broadcast(self,idx,col):
         SharedDataRealTime.Broadcast(
             self.sharedData,
